"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MsgId:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MsgIdEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MsgId.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MSG_ID_UNKNOWN: _MsgId.ValueType  # 0
    REQ_DLOPEN: _MsgId.ValueType  # 1
    REQ_DLCLOSE: _MsgId.ValueType  # 2
    REQ_DLSYM: _MsgId.ValueType  # 3
    REQ_PEEK: _MsgId.ValueType  # 4
    REQ_POKE: _MsgId.ValueType  # 5
    REQ_EXEC: _MsgId.ValueType  # 6
    REQ_CALL: _MsgId.ValueType  # 7
    REQ_CLOSE_CLIENT: _MsgId.ValueType  # 8
    REQ_LIST_DIR: _MsgId.ValueType  # 9
    REQ_DUMMY_BLOCK: _MsgId.ValueType  # 10
    REQ_GET_CLASS_LIST: _MsgId.ValueType  # 11
    REQ_SHOW_OBJECT: _MsgId.ValueType  # 12
    REQ_SHOW_CLASS: _MsgId.ValueType  # 13

class MsgId(_MsgId, metaclass=_MsgIdEnumTypeWrapper): ...

MSG_ID_UNKNOWN: MsgId.ValueType  # 0
REQ_DLOPEN: MsgId.ValueType  # 1
REQ_DLCLOSE: MsgId.ValueType  # 2
REQ_DLSYM: MsgId.ValueType  # 3
REQ_PEEK: MsgId.ValueType  # 4
REQ_POKE: MsgId.ValueType  # 5
REQ_EXEC: MsgId.ValueType  # 6
REQ_CALL: MsgId.ValueType  # 7
REQ_CLOSE_CLIENT: MsgId.ValueType  # 8
REQ_LIST_DIR: MsgId.ValueType  # 9
REQ_DUMMY_BLOCK: MsgId.ValueType  # 10
REQ_GET_CLASS_LIST: MsgId.ValueType  # 11
REQ_SHOW_OBJECT: MsgId.ValueType  # 12
REQ_SHOW_CLASS: MsgId.ValueType  # 13
Global___MsgId: typing_extensions.TypeAlias = MsgId

@typing.final
class RequestShowObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    address: builtins.int
    def __init__(
        self,
        *,
        address: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address"]) -> None: ...

Global___RequestShowObject: typing_extensions.TypeAlias = RequestShowObject

@typing.final
class ReplyShowObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    description: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description"]) -> None: ...

Global___ReplyShowObject: typing_extensions.TypeAlias = ReplyShowObject

@typing.final
class RequestShowClass(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    address: builtins.int
    def __init__(
        self,
        *,
        address: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address"]) -> None: ...

Global___RequestShowClass: typing_extensions.TypeAlias = RequestShowClass

@typing.final
class ReplyShowClass(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    description: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description"]) -> None: ...

Global___ReplyShowClass: typing_extensions.TypeAlias = ReplyShowClass

@typing.final
class RequestDlopen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILENAME_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    filename: builtins.str
    mode: builtins.int
    def __init__(
        self,
        *,
        filename: builtins.str = ...,
        mode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filename", b"filename", "mode", b"mode"]) -> None: ...

Global___RequestDlopen: typing_extensions.TypeAlias = RequestDlopen

@typing.final
class ReplyDlopen(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HANDLE_FIELD_NUMBER: builtins.int
    handle: builtins.int
    def __init__(
        self,
        *,
        handle: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["handle", b"handle"]) -> None: ...

Global___ReplyDlopen: typing_extensions.TypeAlias = ReplyDlopen

@typing.final
class RequestDlclose(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HANDLE_FIELD_NUMBER: builtins.int
    handle: builtins.int
    def __init__(
        self,
        *,
        handle: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["handle", b"handle"]) -> None: ...

Global___RequestDlclose: typing_extensions.TypeAlias = RequestDlclose

@typing.final
class ReplyDlclose(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RES_FIELD_NUMBER: builtins.int
    res: builtins.int
    def __init__(
        self,
        *,
        res: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["res", b"res"]) -> None: ...

Global___ReplyDlclose: typing_extensions.TypeAlias = ReplyDlclose

@typing.final
class RequestDlsym(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HANDLE_FIELD_NUMBER: builtins.int
    SYMBOL_NAME_FIELD_NUMBER: builtins.int
    handle: builtins.int
    symbol_name: builtins.str
    def __init__(
        self,
        *,
        handle: builtins.int = ...,
        symbol_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["handle", b"handle", "symbol_name", b"symbol_name"]) -> None: ...

Global___RequestDlsym: typing_extensions.TypeAlias = RequestDlsym

@typing.final
class ReplyDlsym(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PTR_FIELD_NUMBER: builtins.int
    ptr: builtins.int
    def __init__(
        self,
        *,
        ptr: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ptr", b"ptr"]) -> None: ...

Global___ReplyDlsym: typing_extensions.TypeAlias = ReplyDlsym

@typing.final
class RequestExec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_FIELD_NUMBER: builtins.int
    ARGV_FIELD_NUMBER: builtins.int
    ENVP_FIELD_NUMBER: builtins.int
    background: builtins.bool
    @property
    def argv(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def envp(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        background: builtins.bool = ...,
        argv: collections.abc.Iterable[builtins.str] | None = ...,
        envp: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["argv", b"argv", "background", b"background", "envp", b"envp"]) -> None: ...

Global___RequestExec: typing_extensions.TypeAlias = RequestExec

@typing.final
class ReplyExec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    FD_FIELD_NUMBER: builtins.int
    pid: builtins.int
    fd: builtins.int
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        fd: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["fd", b"fd", "pid", b"pid"]) -> None: ...

Global___ReplyExec: typing_extensions.TypeAlias = ReplyExec

@typing.final
class RequestCall(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    VA_LIST_INDEX_FIELD_NUMBER: builtins.int
    ARGV_FIELD_NUMBER: builtins.int
    address: builtins.int
    va_list_index: builtins.int
    @property
    def argv(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Argument]: ...
    def __init__(
        self,
        *,
        address: builtins.int = ...,
        va_list_index: builtins.int = ...,
        argv: collections.abc.Iterable[Global___Argument] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "argv", b"argv", "va_list_index", b"va_list_index"]) -> None: ...

Global___RequestCall: typing_extensions.TypeAlias = RequestCall

@typing.final
class ReplyCall(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARM_REGISTERS_FIELD_NUMBER: builtins.int
    RETURN_VALUE_FIELD_NUMBER: builtins.int
    return_value: builtins.int
    @property
    def arm_registers(self) -> Global___ReturnRegistersArm: ...
    def __init__(
        self,
        *,
        arm_registers: Global___ReturnRegistersArm | None = ...,
        return_value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["arm_registers", b"arm_registers", "return_value", b"return_value", "return_values", b"return_values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["arm_registers", b"arm_registers", "return_value", b"return_value", "return_values", b"return_values"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["return_values", b"return_values"]) -> typing.Literal["arm_registers", "return_value"] | None: ...

Global___ReplyCall: typing_extensions.TypeAlias = ReplyCall

@typing.final
class RequestPeek(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    address: builtins.int
    size: builtins.int
    def __init__(
        self,
        *,
        address: builtins.int = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "size", b"size"]) -> None: ...

Global___RequestPeek: typing_extensions.TypeAlias = RequestPeek

@typing.final
class ReplyPeek(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data", b"data"]) -> None: ...

Global___ReplyPeek: typing_extensions.TypeAlias = ReplyPeek

@typing.final
class RequestPoke(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    address: builtins.int
    data: builtins.bytes
    def __init__(
        self,
        *,
        address: builtins.int = ...,
        data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "data", b"data"]) -> None: ...

Global___RequestPoke: typing_extensions.TypeAlias = RequestPoke

@typing.final
class ReplyPoke(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ReplyPoke: typing_extensions.TypeAlias = ReplyPoke

@typing.final
class RequestListDir(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

Global___RequestListDir: typing_extensions.TypeAlias = RequestListDir

@typing.final
class RequestDummyBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___RequestDummyBlock: typing_extensions.TypeAlias = RequestDummyBlock

@typing.final
class ReplyDummyBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    address: builtins.int
    size: builtins.int
    def __init__(
        self,
        *,
        address: builtins.int = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "size", b"size"]) -> None: ...

Global___ReplyDummyBlock: typing_extensions.TypeAlias = ReplyDummyBlock

@typing.final
class RequestGetClassList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___RequestGetClassList: typing_extensions.TypeAlias = RequestGetClassList

@typing.final
class ObjcClass(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    address: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        address: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "name", b"name"]) -> None: ...

Global___ObjcClass: typing_extensions.TypeAlias = ObjcClass

@typing.final
class ReplyGetClassList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLASSES_FIELD_NUMBER: builtins.int
    @property
    def classes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ObjcClass]: ...
    def __init__(
        self,
        *,
        classes: collections.abc.Iterable[Global___ObjcClass] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["classes", b"classes"]) -> None: ...

Global___ReplyGetClassList: typing_extensions.TypeAlias = ReplyGetClassList

@typing.final
class ReplyError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["message", b"message"]) -> None: ...

Global___ReplyError: typing_extensions.TypeAlias = ReplyError

@typing.final
class ReplyListDir(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIR_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def dir_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___DirEntry]: ...
    def __init__(
        self,
        *,
        dir_entries: collections.abc.Iterable[Global___DirEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dir_entries", b"dir_entries"]) -> None: ...

Global___ReplyListDir: typing_extensions.TypeAlias = ReplyListDir

@typing.final
class RequestCloseClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___RequestCloseClient: typing_extensions.TypeAlias = RequestCloseClient

@typing.final
class ReplyCloseClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ReplyCloseClient: typing_extensions.TypeAlias = ReplyCloseClient

@typing.final
class DirEntryStat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERRNO1_FIELD_NUMBER: builtins.int
    ST_DEV_FIELD_NUMBER: builtins.int
    ST_MODE_FIELD_NUMBER: builtins.int
    ST_NLINK_FIELD_NUMBER: builtins.int
    ST_INO_FIELD_NUMBER: builtins.int
    ST_UID_FIELD_NUMBER: builtins.int
    ST_GID_FIELD_NUMBER: builtins.int
    ST_RDEV_FIELD_NUMBER: builtins.int
    ST_SIZE_FIELD_NUMBER: builtins.int
    ST_BLOCKS_FIELD_NUMBER: builtins.int
    ST_BLKSIZE_FIELD_NUMBER: builtins.int
    ST_ATIME1_FIELD_NUMBER: builtins.int
    ST_MTIME1_FIELD_NUMBER: builtins.int
    ST_CTIME1_FIELD_NUMBER: builtins.int
    errno1: builtins.int
    st_dev: builtins.int
    st_mode: builtins.int
    st_nlink: builtins.int
    st_ino: builtins.int
    st_uid: builtins.int
    st_gid: builtins.int
    st_rdev: builtins.int
    st_size: builtins.int
    st_blocks: builtins.int
    st_blksize: builtins.int
    st_atime1: builtins.int
    st_mtime1: builtins.int
    st_ctime1: builtins.int
    def __init__(
        self,
        *,
        errno1: builtins.int = ...,
        st_dev: builtins.int = ...,
        st_mode: builtins.int = ...,
        st_nlink: builtins.int = ...,
        st_ino: builtins.int = ...,
        st_uid: builtins.int = ...,
        st_gid: builtins.int = ...,
        st_rdev: builtins.int = ...,
        st_size: builtins.int = ...,
        st_blocks: builtins.int = ...,
        st_blksize: builtins.int = ...,
        st_atime1: builtins.int = ...,
        st_mtime1: builtins.int = ...,
        st_ctime1: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["errno1", b"errno1", "st_atime1", b"st_atime1", "st_blksize", b"st_blksize", "st_blocks", b"st_blocks", "st_ctime1", b"st_ctime1", "st_dev", b"st_dev", "st_gid", b"st_gid", "st_ino", b"st_ino", "st_mode", b"st_mode", "st_mtime1", b"st_mtime1", "st_nlink", b"st_nlink", "st_rdev", b"st_rdev", "st_size", b"st_size", "st_uid", b"st_uid"]) -> None: ...

Global___DirEntryStat: typing_extensions.TypeAlias = DirEntryStat

@typing.final
class DirEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    D_TYPE_FIELD_NUMBER: builtins.int
    D_NAME_FIELD_NUMBER: builtins.int
    LSTAT_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    d_type: builtins.int
    d_name: builtins.str
    @property
    def lstat(self) -> Global___DirEntryStat: ...
    @property
    def stat(self) -> Global___DirEntryStat: ...
    def __init__(
        self,
        *,
        d_type: builtins.int = ...,
        d_name: builtins.str = ...,
        lstat: Global___DirEntryStat | None = ...,
        stat: Global___DirEntryStat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lstat", b"lstat", "stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["d_name", b"d_name", "d_type", b"d_type", "lstat", b"lstat", "stat", b"stat"]) -> None: ...

Global___DirEntry: typing_extensions.TypeAlias = DirEntry

@typing.final
class ReturnRegistersArm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    X0_FIELD_NUMBER: builtins.int
    X1_FIELD_NUMBER: builtins.int
    X2_FIELD_NUMBER: builtins.int
    X3_FIELD_NUMBER: builtins.int
    X4_FIELD_NUMBER: builtins.int
    X5_FIELD_NUMBER: builtins.int
    X6_FIELD_NUMBER: builtins.int
    X7_FIELD_NUMBER: builtins.int
    D0_FIELD_NUMBER: builtins.int
    D1_FIELD_NUMBER: builtins.int
    D2_FIELD_NUMBER: builtins.int
    D3_FIELD_NUMBER: builtins.int
    D4_FIELD_NUMBER: builtins.int
    D5_FIELD_NUMBER: builtins.int
    D6_FIELD_NUMBER: builtins.int
    D7_FIELD_NUMBER: builtins.int
    x0: builtins.int
    x1: builtins.int
    x2: builtins.int
    x3: builtins.int
    x4: builtins.int
    x5: builtins.int
    x6: builtins.int
    x7: builtins.int
    d0: builtins.float
    d1: builtins.float
    d2: builtins.float
    d3: builtins.float
    d4: builtins.float
    d5: builtins.float
    d6: builtins.float
    d7: builtins.float
    def __init__(
        self,
        *,
        x0: builtins.int = ...,
        x1: builtins.int = ...,
        x2: builtins.int = ...,
        x3: builtins.int = ...,
        x4: builtins.int = ...,
        x5: builtins.int = ...,
        x6: builtins.int = ...,
        x7: builtins.int = ...,
        d0: builtins.float = ...,
        d1: builtins.float = ...,
        d2: builtins.float = ...,
        d3: builtins.float = ...,
        d4: builtins.float = ...,
        d5: builtins.float = ...,
        d6: builtins.float = ...,
        d7: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["d0", b"d0", "d1", b"d1", "d2", b"d2", "d3", b"d3", "d4", b"d4", "d5", b"d5", "d6", b"d6", "d7", b"d7", "x0", b"x0", "x1", b"x1", "x2", b"x2", "x3", b"x3", "x4", b"x4", "x5", b"x5", "x6", b"x6", "x7", b"x7"]) -> None: ...

Global___ReturnRegistersArm: typing_extensions.TypeAlias = ReturnRegistersArm

@typing.final
class Argument(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    V_INT_FIELD_NUMBER: builtins.int
    V_DOUBLE_FIELD_NUMBER: builtins.int
    V_STR_FIELD_NUMBER: builtins.int
    V_BYTES_FIELD_NUMBER: builtins.int
    v_int: builtins.int
    v_double: builtins.float
    v_str: builtins.str
    v_bytes: builtins.bytes
    def __init__(
        self,
        *,
        v_int: builtins.int = ...,
        v_double: builtins.float = ...,
        v_str: builtins.str = ...,
        v_bytes: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["type", b"type", "v_bytes", b"v_bytes", "v_double", b"v_double", "v_int", b"v_int", "v_str", b"v_str"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["type", b"type", "v_bytes", b"v_bytes", "v_double", b"v_double", "v_int", b"v_int", "v_str", b"v_str"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["v_int", "v_double", "v_str", "v_bytes"] | None: ...

Global___Argument: typing_extensions.TypeAlias = Argument
